package interestRate;

/**
   A node of a linked list.
   @author Somesh Jha
   */

public class Node {

  //Next and previous links
  public Node prev, next;
  public KeyInterface key;


  //No of successors of this node
  //initially this is only 2 because
  //of the binomial model
  static final int NO_OF_SUCC = 2;

  Node succ[] = new Node[NO_OF_SUCC];

  /**
     @param k Key of that node.
     */
  public Node(KeyInterface k) {
    key = k;
    prev=next=null;
  }//end of Node


  /**
     Search a node that is a successor of this node
     and has a specified key.
     @param k Specifed Key
     */
  public Node Search(KeyInterface k) {
    Node x = this;
    while (x != null) {
      if (x.key.isEqual(k))  return(x);
      else x = x.next;
    }
    //didn't find the key
    return(x);
  }//end of Search

  /**
     Delete this node
     */
  public void Delete() {
    Node prev1 = this.prev;
    Node next1 = this.next;
    System.out.print("Node:Delete: prev and next ");

    if (prev1 != null) prev1.next = next1;
    if (next1 != null) next1.prev = prev1;
  }//end of Delete
    

  /**
     Insert a node after a specified node
     */
  public void InsertAfter(Node x) {
    Node temp = this.next;
    this.next = x;
    x.prev = this;
    x.next = temp;
    if (temp != null) temp.prev = x;
  }

  /**
     Insert a node before a specified node.
     */
  public void InsertBefore(Node x) {
    Node temp = this.prev;
    this.prev = x;
    x.next = this;
    x.prev = temp;

    if (temp != null)
    {
       temp.next = x;
    }
  }


  /**
     Insert element in the link list
     starting from the node if not already
     there
     */
  public Node InsertElement(KeyInterface k) {
    Node x = Search(k);
    //element not there
    if (x == null) {
      x = new Node(k);
      InsertAfter(x);
    }
    return(x);
  }//end of InsertElement

  /**
     print the linklist starting at the node
     */
  public void print() {
    Node x=this;
    while (x != null) {
      x.key.print();
      x = x.next;
    }
  }//end of print
     


    
}//end of class Node
