/**
 * The <code>AsianCallOption</code> class extends
 * the AbstractOption class to provide an implementation
 * of a Asian Call Option.  
 * <p>
 * You must specify the methods that are used by the 
 * base class to compute option values.
 * See EuropeanCallOption.java for an example.
 *
 * Put your name in the author field below!
 *
 * @author
 */

package optionCalc;

public class AsianCallOption extends AbstractOption 
{
/**
   * The (double) strike price 
   */
  double K;

  /**
   * Constructs a AsianCallOption object, this function
   * calls the super class constructor in AbstractOption
   *
   * @param   T			the (int) time Horizon
   * @param   r			the (double) short rate
   * @param   u			the (double) up-factor
   * @param   d			the (double) down-factor
   * @param   s_0		the (double) initial stock price
   */
  public AsianCallOption(int T, double r, double u,
			double d, double s_0) 
  {
      //Call the super class constructor
      super(T,r,u,d,s_0);
  }

  /**
   * Constructs a AsianCallOption object, this function
   * calls the super class constructor in AbstractOption and
   * sets the strike price.
   *
   * @param   T			the (int) time Horizon
   * @param   r			the (double) short rate
   * @param   u			the (double) up-factor
   * @param   d			the (double) down-factor
   * @param   s_0		the (double) initial stock price
   * @param   strike            the (double) strike price
   */
  public AsianCallOption(int T, double r, double u,
			double d, double s_0, double strike) 
  {
      super(T,r,u,d,s_0);
      K = strike;  
  }


  /**
   * Sets the strike price
   */
  public void setStrike(double strike) 
  {
      strike = K;
  }

  /**
   * Determines how the auxillary process evolves
   * over time.  This method is an implementation
   * of the abstract F method in the base class.
   * For this option, we don't need 
   * an aux process, so we'll set it equal to the 
   * stock price.  
   *
   * @param   s     the (double) new stock price
   * @param   x	    the (double) old value of the aux process
   */
  public double F(double s, double x) 
  {
      return(s+x);
  }
  /**
   * Determines the payoff in terms of the stock price,
   * and strike price.   This method is an implementation
   * of the abstract payoff method in the base class.
   *
   * @param   s     the (double) stock price
   * @param   x	    the (double) value of the aux process
   * @param   t     the (int) time value
   */
  public double payoff(double s, double x, int t) 
  {
      double value = (x/(1+t))-K;
      if (value < 0) 
      {
          value=0.0;
      }

      return(value);
  }

}
